@@ -17,9 +17,17 @@ import math
 import tempfile
 import threading
 import queue
+import re
 
 def write2path(lines,path='',encoding='utf-8',method='lines',append='w',wrap=False):
-    """ 读取文件 """
+    """ 写入数组到本地文件
+        lines - 字符串数组
+        path - 本地文件路径
+        encoding - 编码格式
+        method - 写入类型 (lines-多行数据写入 line-写入字符串)
+        append - 操作模式 (w-覆盖写入 a-追加)
+        wrap - 自动换行 (数组中每条数据后加换行符)
+    """
     if not path: path=getTime()+'.txt'
     with open(path,append,encoding=encoding) as fw:
         if method=='lines':
@@ -30,7 +38,13 @@ def write2path(lines,path='',encoding='utf-8',method='lines',append='w',wrap=Fal
             fw.write(lines)
 
 def append2path(line,path,encoding='utf-8',method='line',append='a'):
-    """ 文件末尾追加内容，自动换行 """
+    """ 文件末尾追加内容
+            line - 追加的内容，自动在内容后加换行
+            path - 本地文件路径
+            encoding - 编码格式
+            method - 写入类型 (lines-多行数据写入 line-写入字符串)
+            append - 操作模式 (a-追加 w-覆盖写入)
+    """
     with open(path,append,encoding=encoding) as fw:
         if method=='line':
             fw.write(line+'\n')
@@ -38,7 +52,13 @@ def append2path(line,path,encoding='utf-8',method='line',append='a'):
             fw.writelines(line)
 
 def read_path(path,method='lines',encoding='utf-8',errors='strict',strip=False):
-    """ 读取文件 """
+    """ 读取文件
+            path - 本地文件路径
+            method - 读取类型 (lines-以多行数据读取 line-以单个字符串读取)
+            encoding - 编码格式
+            errors - 编码错误处理 (strict-严格模式，错误报异常 ignore-忽略错误的内容)
+            strip - 是否去除每条数据后面的换行符
+    """
     with open(path,'r',encoding=encoding,errors=errors) as fr:
         if method == "lines":
             all_lines = fr.readlines()
@@ -49,7 +69,9 @@ def read_path(path,method='lines',encoding='utf-8',errors='strict',strip=False):
         return all_lines
 
 def print_list(array,index=False):
-    """ 打印list内容 """
+    """ 打印list内容
+            index - 是否打印索引
+    """
     if index:
         for i,val in enumerate(array):
             print(i,val)
@@ -98,7 +120,9 @@ def getTime(timestamp='',format='y'):
         return time.strftime(format_str, time.localtime())
 
 def getTimestamp(is_ms=False):
-    """ 获取当前时间戳 """
+    """ 获取当前时间戳
+            is_ms - 毫秒时间戳
+    """
     ts=time.time()
     if is_ms:
         return int(ts * 1000)
@@ -139,6 +163,18 @@ def get_file_md5(file_path):
         md5 = str(hash_code).lower()
     return md5
 
+def get_file_sha256(file_path):
+    """ 获取文件sha256 """
+    sha256obj = None
+    if os.path.isfile(file_path):
+        f = open(file_path, 'rb')
+        sha256obj = hashlib.sha256()
+        sha256obj.update(f.read())
+        hash_value = sha256obj.hexdigest()
+        f.close()
+        sha256obj = str(hash_value).lower()
+    return sha256obj
+
 def get_file_chardet(file_path):
     import chardet
     f = open(file_path, "rb")
@@ -354,7 +390,7 @@ def run_multi_thread_task(all_items, user_func, thread_num=os.cpu_count()+1):
     for item in all_items:
         q.put(item)
 
-    def func_task(q, res_list):
+    def func_task(q):
         while True:
             item = q.get()
             res_list.append(user_func(item))
@@ -518,6 +554,10 @@ def rename_file_md5(folder,over_write=True):
         all_md5_name.append(md5_name)
         movefile(f,new_file_path)
 
+def format_file_name(file_name,pattern="[a-zA-Z0-9_\.]"):
+    new_file_name="".join(search_by_regular(pattern,file_name))
+    return new_file_name
+
 def change_venv(old_project_path,new_project_path):
     '''
         解决venv修改位置后失效问题
@@ -560,3 +600,7 @@ def split_path(file_path):
     folder_path=os.path.dirname(file_path)
     return folder_path,file_name
 
+def search_by_regular(pattern,content):
+    regex = re.compile(pattern)
+    return regex.findall(content)
+
